@@ -7,7 +7,7 @@ from struct import pack
 from mc_connection import mc
 
 def _mc_get_multi(self, args_list):
-    result = self.get_list(key_list)
+    result = self.get_list(args_list)
     return dict(zip(args_list, result))
 
 def _mc_decorator(self, key, expire=0):
