@@ -258,8 +258,10 @@ class Query(object):
         db = db or cls.get_db()
         cursor = db.cursor()
         try:
-            cursor.execute(sql, values)
-            
+            if values:
+                cursor.execute(sql, values)
+            else: 
+                cursor.execute(sql)
             if db.b_commit:
                 cls.commit(db)
         except Exception, ex:
