@@ -1,16 +1,17 @@
 #coding:utf-8
 from sqlbean.db.mc_connection import mc
 class McTotal(object):
-    def __init__(self, get_count, mc_key):
+    def __init__(self, get_count, mc_key, timeout=36000):
         self.mc_key = mc_key
         self.get_count = get_count
+        self.timeout = timeout
 
     def __call__(self, key):
         mk = self.mc_key%key
         count = mc.get(mk)
         if count is None:
             count = self.get_count(key) or 0
-        mc.set(mk, count)
+            mc.set(mk, count, self.timeout)
         return count
 
     def get_multi(self, keys):
@@ -21,7 +22,7 @@ class McTotal(object):
         for k, mck in mc_key_list.iteritems():
             v = result.get(mck)
             if v is None:
-                v = self.get_count(key) or 0
+                v = self.get_count(k) or 0
                 mc.set(mck, v)
             r[k] = v
         return r
@@ -32,6 +33,9 @@ class McTotal(object):
             i.total = d[i.id]
         return ins
 
+    def delete(self,key):
+        mk = self.mc_key%key
+        mc.delete(mk)
 
     def get_list(self, keys):
         r = self.get_multi(keys)
