@@ -283,3 +283,9 @@ class McModel(object):
         ins.save()
 
         return ins
+    @classmethod
+    def mc_bind(cls,xxx_list,property,key="id"):
+           d = dict( (getattr(i,key),i) for i in xxx_list  )
+           r = cls.mc_get_multi(d)
+           for k,v in d.iteritems():
+                 v.__dict__[property] = r.get(k)
