@@ -1,5 +1,5 @@
 from sqlbean.db.query import Query
-from sqlbean.db.mc import mc, MMcCache, McCache
+from sqlbean.db.mc import mc, McCacheM, McCache,McCacheA
 from sqlbean.db.relations import ForeignKey, OneToMany
 from sqlbean.model import Model
 from sqlbean.mcmodel import McModel
